--! Save-A-Line  Example Code for GOOi, Alberto Lara's Android Oriented GUI Library
-- Here: A small working snippet of code to demonstrate the Text Field Widget at work.
-- It saves a line of text to the default path on your system (A feature of love.filesystem)
-- (The interesting stuff happens from line 38 on.)
-- Sept., 5th, 2017  -- Bernd Stein (BörnedByLOVE)

require "gooi"

-- Info concerning love.filesystem.write: Visit https://love2d.org/wiki/love.filesystem !!!
mySystemsPath = "~/.local/share/love/"  -- This is your path, if you are on linux...
-- mySystemsPath = "C:\Documents and Settings\user\Application Data\LOVE\" -- Your path on WinXP.
-- mySystemsPath = "C:\Users\user\AppData\Roaming\LOVE"  -- Your path, if you are on Win7, 8 or 10.
-- mySystemsPath = "/Users/user/Library/Application Support/LOVE/"  -- Your path on Mac.

function love.load()
    gr = love.graphics
    kb = love.keyboard
    mo = love.mouse
    gr.setBackgroundColor(111, 105, 111)

    style = {
        font = gr.newFont("fonts/Arimo-Bold.ttf", 22),
        radius = 5,
        innerRadius = 3,
        showBorder = true,
    }
    gooi.setStyle(style)
    gooi.desktopMode()
    
    gooi.shadow()       -- 1 of three different Modes!

    -- GOOi-GUI-Elements
    lbl1 = gooi.newLabel({x = 100, y = 20, text = "Save a line of text to...     "..mySystemsPath})
    lbl2 = gooi.newLabel({x = 100, y = 50, text = "Quit with Q !"})
    
    txt1 = gooi.newText({text = "A text field", x = 70, y = 110, w = 350, h = 35}):setText("EUREKA! - I got it now!")
    
    saveButton = gooi.newButton({text = "Save", x = 440, y = 110, w = 80, h = 35}):onRelease(function()
        love.filesystem.setIdentity("MyNewApp7")  -- creates a new folder in your path directory
        mynotetext = txt1:getText()               -- Reads out the line of text in Text Field txt1
        love.filesystem.write("mynote.txt", mynotetext, all)  -- Saves the text line to your system's path
    end)
    
    exitButton = gooi.newButton({text = "Quit", x = 280, y = 180, w = 150, h = 50})
        :setIcon("imgs/coin.png"):danger()
        :setTooltip("Exit here!")
        :onRelease(function()
            gooi.confirm({
                text = "Are you sure?",
                ok = function()
                    quit()
                end
            })
        end)
end

function love.update(dt)
    gooi.update(dt)
end
  
function love.draw()
  gooi.draw()
end

function love.mousereleased(x, y, button) gooi.released() end
function love.mousepressed(x, y, button)  gooi.pressed() end

function love.textinput(text) gooi.textinput(text) end

function love.keypressed(key, scancode, isrepeat)
    gooi.keypressed(key, scancode, isrepeat)
    if key == "q" then
        quit()
    end
end
function love.keyreleased(key, scancode)
    gooi.keyreleased(key, scancode)
end

function quit()
    love.event.quit()
end
